Documentation
¶
Overview ¶
Package agent provides access to agent integration files embedded in the assets filesystem.
Package agent provides access to agent integration files embedded
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CopilotInstructions ¶
CopilotInstructions reads the embedded Copilot instructions template.
Returns:
- []byte: Template content from hooks/copilot-instructions.md
- error: Non-nil if the file is not found or read fails
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.