example

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package example provides usage examples shown when the add command receives no content for a given entry type.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ForType

func ForType(fileType string) string

ForType returns example usage strings for a given entry type.

The examples are loaded from the embedded commands.yaml asset. Entry type keys (decision, task, learning, convention) are defined in config/entry and match the YAML keys in examples.yaml.

Parameters:

  • fileType: Entry type (e.g., "decision", "task", "learning", "convention")

Returns:

  • string: Formatted example commands; returns a generic example for unrecognized types

Types

This section is empty.

Jump to