remind

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Package remind manages session-scoped reminders stored in .context/reminders.json.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Cmd

func Cmd() *cobra.Command

Cmd returns the remind command with subcommands.

When invoked with arguments and no subcommand, it adds a reminder. When invoked with no arguments, it lists all reminders.

Returns:

  • *cobra.Command: Configured remind command with subcommands

Types

This section is empty.

Directories

Path Synopsis
cmd
add
Package add implements the ctx remind add subcommand.
Package add implements the ctx remind add subcommand.
dismiss
Package dismiss implements the ctx remind dismiss subcommand.
Package dismiss implements the ctx remind dismiss subcommand.
list
Package list implements the ctx remind list subcommand.
Package list implements the ctx remind list subcommand.
Package core provides shared reminder types and storage operations used by all remind subcommand packages.
Package core provides shared reminder types and storage operations used by all remind subcommand packages.

Jump to