zensical

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package zensical wraps the zensical static site generator binary, providing a Go interface for building and serving sites.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(dir string) error

Run launches zensical serve in the given directory.

Parameters:

  • dir: Working directory for the zensical process

Returns:

  • error: Non-nil if the process fails

Types

This section is empty.

Jump to